==> cucumber-groovy-1.2.2-sources.jar: cucumber/api/groovy/ES.java <==
package cucumber.api.groovy;

import groovy.lang.Closure;
import cucumber.runtime.groovy.*;

import java.util.regex.Pattern;

public class ES {

    public static void Cuando(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Cuando(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Dada(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Dada(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Dadas(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Dadas(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Dado(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Dado(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Dados(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Dados(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Entonces(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Entonces(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Pero(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Pero(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Y(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Y(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

}

==> cucumber-groovy-2.0.1-sources.jar: cucumber/api/groovy/ES.java <==
package cucumber.api.groovy;

import groovy.lang.Closure;
import cucumber.runtime.groovy.*;

import java.util.regex.Pattern;

public class ES {

    public static void Dado(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Dado(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Dada(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Dada(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Dados(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Dados(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Dadas(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Dadas(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Cuando(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Cuando(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Entonces(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Entonces(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Y(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Y(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void E(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void E(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Pero(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Pero(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

}
